isibib2df <- function(D) {
  # this is a legacy function (for old scripts)
  DATA <- bib2df(D, dbsource = "isi")

  return(DATA)
}
